package com.pnkx.system.mapper;

import com.pnkx.system.domain.SysAppUpdateLog;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;

/**
 * @author PHY
 * @classname PxAppMapper
 * @data 2021/12/1 9:52
 * @description 描述
 */
@Mapper
public interface SysAppMapper {

    /**
     * 获取最新版app信息
     *
     * @return 最新版app信息
     */
    SysAppUpdateLog getNewestAppInfo();

    /**
     * 查询app更新日志列表
     *
     * @param appUpdateLog app更新日志
     * @return app更新日志集合
     */
    public List<SysAppUpdateLog> selectAppUpdateLogList(SysAppUpdateLog appUpdateLog);

    /**
     * 查询app更新日志
     *
     * @param id app更新日志ID
     * @return app更新日志
     */
    public SysAppUpdateLog selectAppUpdateLogById(Long id);

    /**
     * 新增app更新日志
     *
     * @param appUpdateLog app更新日志
     * @return 结果
     */
    public int insertAppUpdateLog(SysAppUpdateLog appUpdateLog);

    /**
     * 修改app更新日志
     *
     * @param appUpdateLog app更新日志
     * @return 结果
     */
    public int updateAppUpdateLog(SysAppUpdateLog appUpdateLog);

    /**
     * 删除app更新日志
     *
     * @param id app更新日志ID
     * @return 结果
     */
    public int deleteAppUpdateLogById(Long id);

    /**
     * 批量删除app更新日志
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteAppUpdateLogByIds(Long[] ids);
}
